summaryrefslogtreecommitdiffstats
path: root/src/arch/i386/firmware/pcbios/hidemem.c
diff options
context:
space:
mode:
authorMichael Brown2010-04-19 21:16:01 +0200
committerMichael Brown2010-04-20 00:43:39 +0200
commit8406115834d38bb743e01f35bfd36e835532415e (patch)
treeee1e3106e2cdc645d911ba5643f8414b21fc4c3e /src/arch/i386/firmware/pcbios/hidemem.c
parent[eepro100] Remove link-state checking (diff)
downloadipxe-8406115834d38bb743e01f35bfd36e835532415e.tar.gz
ipxe-8406115834d38bb743e01f35bfd36e835532415e.tar.xz
ipxe-8406115834d38bb743e01f35bfd36e835532415e.zip
[build] Rename gPXE to iPXE
Access to the gpxe.org and etherboot.org domains and associated resources has been revoked by the registrant of the domain. Work around this problem by renaming project from gPXE to iPXE, and updating URLs to match. Also update README, LOG and COPYRIGHTS to remove obsolete information. Signed-off-by: Michael Brown <mcb30@ipxe.org>
Diffstat (limited to 'src/arch/i386/firmware/pcbios/hidemem.c')
-rw-r--r--src/arch/i386/firmware/pcbios/hidemem.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/arch/i386/firmware/pcbios/hidemem.c b/src/arch/i386/firmware/pcbios/hidemem.c
index 17082c35..322be9e4 100644
--- a/src/arch/i386/firmware/pcbios/hidemem.c
+++ b/src/arch/i386/firmware/pcbios/hidemem.c
@@ -22,9 +22,9 @@ FILE_LICENCE ( GPL2_OR_LATER );
#include <biosint.h>
#include <basemem.h>
#include <fakee820.h>
-#include <gpxe/init.h>
-#include <gpxe/memmap.h>
-#include <gpxe/hidemem.h>
+#include <ipxe/init.h>
+#include <ipxe/memmap.h>
+#include <ipxe/hidemem.h>
/** Set to true if you want to test a fake E820 map */
#define FAKE_E820 0
@@ -33,7 +33,7 @@ FILE_LICENCE ( GPL2_OR_LATER );
#define ALIGN_HIDDEN 4096 /* 4kB page alignment should be enough */
/**
* A hidden region of gPXE
*
* This represents a region that will be edited out of the system's
* memory map.
@@ -138,7 +138,7 @@ static void hide_etherboot ( void ) {
unsigned int fbms;
/* Dump memory map before mangling */
- DBG ( "Hiding gPXE from system memory map\n" );
+ DBG ( "Hiding iPXE from system memory map\n" );
get_memmap ( &memmap );
/* Hook in fake E820 map, if we're testing one */
@@ -178,7 +178,7 @@ static void hide_etherboot ( void ) {
&int15_vector );
/* Dump memory map after mangling */
- DBG ( "Hidden gPXE from system memory map\n" );
+ DBG ( "Hidden iPXE from system memory map\n" );
get_memmap ( &memmap );
}
@@ -33,7 +33,7 @@ FILE_LICENCE ( GPL2_OR_LATER );
#define ALIGN_HIDDEN 4096 /* 4kB page alignment should be enough */
/**
- * A hidden region of gPXE
+ * A hidden region of iPXE
*
* This represents a region that will be edited out of the system's